<?php
/**
* The header for CleanWP theme.
*
* @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
*
* @package CleanWP WordPress Theme
* @copyright Copyright (C) 2022 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?> itemscope="itemscope" itemtype="http://schema.org/WebPage">
<?php wp_body_open(); ?>
<div id="wrapper">
<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'cleanwp' ); ?></a>

<?php cleanwp_before_header(); ?>

<header id="masthead" class="site-header" itemscope="itemscope" itemtype="http://schema.org/WPHeader" role="banner">

<div id="site-top">
<div id="blogname">
<?php if ( get_header_image() ) : ?>
    <div class="site-branding site-branding-block site-branding-header-image">
    <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" class="header-image-link">
        <img src="<?php header_image(); ?>" width="<?php echo esc_attr(get_custom_header()->width); ?>" height="<?php echo esc_attr(get_custom_header()->height); ?>" alt="" class="header-image"/>
    </a>
    </div>
<?php endif; ?>

<?php if ( has_custom_logo() ) : ?>
    <div class="site-branding site-branding-block site-branding-logo-active cleanwp-text-center">
    <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" class="cleanwp-logo-img-link">
        <img src="<?php echo esc_url( cleanwp_custom_logo() ); ?>" alt="" class="cleanwp-logo-img"/>
    </a>
    <?php if ( is_front_page() && is_home() ) { ?>
            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_home() ) { ?>
            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_singular() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_category() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_tag() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_author() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_archive() && !is_category() && !is_tag() && !is_author() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_search() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_404() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } else { ?>
            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } ?>
    </div>
<?php else: ?>
    <div class="site-branding site-branding-block site-branding-logo-inactive">
    <?php if ( is_front_page() && is_home() ) { ?>
            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_home() ) { ?>
            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_singular() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_category() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_tag() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_author() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_archive() && !is_category() && !is_tag() && !is_author() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_search() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } elseif ( is_404() ) { ?>
            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } else { ?>
            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <p class="site-description"><?php bloginfo( 'description' ); ?></p>
    <?php } ?>
    </div>
<?php endif; ?>
</div>

<?php if ( !(cleanwp_get_option('hide_social_buttons')) ) { ?>
<div class="header-social-icons">
    <?php if ( cleanwp_get_option('facebooklink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('facebooklink') ); ?>" target="_blank" rel="nofollow" class="social-facebook" aria-label="<?php esc_attr_e('Facebook Button','cleanwp'); ?>"><i class="fab fa-facebook" aria-hidden="true" title="<?php esc_attr_e('Facebook','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('twitterlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('twitterlink') ); ?>" target="_blank" rel="nofollow" class="social-twitter" aria-label="<?php esc_attr_e('Twitter Button','cleanwp'); ?>"><i class="fab fa-twitter" aria-hidden="true" title="<?php esc_attr_e('Twitter','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('googlelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('googlelink') ); ?>" target="_blank" rel="nofollow" class="social-googleplus" aria-label="<?php esc_attr_e('Google Plus Button','cleanwp'); ?>"><i class="fab fa-google-plus-g" aria-hidden="true" title="<?php esc_attr_e('Google Plus','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('pinterestlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('pinterestlink') ); ?>" target="_blank" rel="nofollow" class="social-pinterest" aria-label="<?php esc_attr_e('Pinterest Button','cleanwp'); ?>"><i class="fab fa-pinterest" aria-hidden="true" title="<?php esc_attr_e('Pinterest','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('linkedinlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('linkedinlink') ); ?>" target="_blank" rel="nofollow" class="social-linkedin" aria-label="<?php esc_attr_e('Linkedin Button','cleanwp'); ?>"><i class="fab fa-linkedin-in" aria-hidden="true" title="<?php esc_attr_e('Linkedin','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('instagramlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('instagramlink') ); ?>" target="_blank" rel="nofollow" class="social-instagram" aria-label="<?php esc_attr_e('Instagram Button','cleanwp'); ?>"><i class="fab fa-instagram" aria-hidden="true" title="<?php esc_attr_e('Instagram','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('flickrlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('flickrlink') ); ?>" target="_blank" rel="nofollow" class="social-flickr" aria-label="<?php esc_attr_e('Flickr Button','cleanwp'); ?>"><i class="fab fa-flickr" aria-hidden="true" title="<?php esc_attr_e('Flickr','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('youtubelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('youtubelink') ); ?>" target="_blank" rel="nofollow" class="social-youtube" aria-label="<?php esc_attr_e('Youtube Button','cleanwp'); ?>"><i class="fab fa-youtube" aria-hidden="true" title="<?php esc_attr_e('Youtube','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('vimeolink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('vimeolink') ); ?>" target="_blank" rel="nofollow" class="social-vimeo" aria-label="<?php esc_attr_e('Vimeo Button','cleanwp'); ?>"><i class="fab fa-vimeo-v" aria-hidden="true" title="<?php esc_attr_e('Vimeo','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('soundcloudlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('soundcloudlink') ); ?>" target="_blank" rel="nofollow" class="social-soundcloud" aria-label="<?php esc_attr_e('SoundCloud Button','cleanwp'); ?>"><i class="fab fa-soundcloud" aria-hidden="true" title="<?php esc_attr_e('SoundCloud','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('messengerlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('messengerlink') ); ?>" target="_blank" rel="nofollow" class="social-messenger" aria-label="<?php esc_attr_e('Messenger Button','cleanwp'); ?>"><i class="fab fa-facebook-messenger" aria-hidden="true" title="<?php esc_attr_e('Messenger','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('whatsapp_button') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('whatsapp_button') ); ?>" target="_blank" rel="nofollow" class="social-whatsapp" aria-label="<?php esc_attr_e('WhatsApp Button','cleanwp'); ?>"><i class="fab fa-whatsapp" aria-hidden="true" title="<?php esc_attr_e('WhatsApp','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('tiktok_button') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('tiktok_button') ); ?>" target="_blank" rel="nofollow" class="social-tiktok" aria-label="<?php esc_attr_e('TikTok Button','cleanwp'); ?>"><i class="fab fa-tiktok" aria-hidden="true" title="<?php esc_attr_e('TikTok','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('lastfmlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('lastfmlink') ); ?>" target="_blank" rel="nofollow" class="social-lastfm" aria-label="<?php esc_attr_e('Lastfm Button','cleanwp'); ?>"><i class="fab fa-lastfm" aria-hidden="true" title="<?php esc_attr_e('Lastfm','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('mediumlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('mediumlink') ); ?>" target="_blank" rel="nofollow" class="social-medium" aria-label="<?php esc_attr_e('Medium Button','cleanwp'); ?>"><i class="fab fa-medium-m" aria-hidden="true" title="<?php esc_attr_e('Medium','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('githublink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('githublink') ); ?>" target="_blank" rel="nofollow" class="social-github" aria-label="<?php esc_attr_e('Github Button','cleanwp'); ?>"><i class="fab fa-github" aria-hidden="true" title="<?php esc_attr_e('Github','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('bitbucketlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('bitbucketlink') ); ?>" target="_blank" rel="nofollow" class="social-bitbucket" aria-label="<?php esc_attr_e('Bitbucket Button','cleanwp'); ?>"><i class="fab fa-bitbucket" aria-hidden="true" title="<?php esc_attr_e('Bitbucket','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('tumblrlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('tumblrlink') ); ?>" target="_blank" rel="nofollow" class="social-tumblr" aria-label="<?php esc_attr_e('Tumblr Button','cleanwp'); ?>"><i class="fab fa-tumblr" aria-hidden="true" title="<?php esc_attr_e('Tumblr','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('digglink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('digglink') ); ?>" target="_blank" rel="nofollow" class="social-digg" aria-label="<?php esc_attr_e('Digg Button','cleanwp'); ?>"><i class="fab fa-digg" aria-hidden="true" title="<?php esc_attr_e('Digg','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('deliciouslink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('deliciouslink') ); ?>" target="_blank" rel="nofollow" class="social-delicious" aria-label="<?php esc_attr_e('Delicious Button','cleanwp'); ?>"><i class="fab fa-delicious" aria-hidden="true" title="<?php esc_attr_e('Delicious','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('stumblelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('stumblelink') ); ?>" target="_blank" rel="nofollow" class="social-stumbleupon" aria-label="<?php esc_attr_e('Stumbleupon Button','cleanwp'); ?>"><i class="fab fa-stumbleupon" aria-hidden="true" title="<?php esc_attr_e('Stumbleupon','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('mixlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('mixlink') ); ?>" target="_blank" rel="nofollow" class="social-mix" aria-label="<?php esc_attr_e('Mix Button','cleanwp'); ?>"><i class="fab fa-mix" aria-hidden="true" title="<?php esc_attr_e('Mix','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('redditlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('redditlink') ); ?>" target="_blank" rel="nofollow" class="social-reddit" aria-label="<?php esc_attr_e('Reddit Button','cleanwp'); ?>"><i class="fab fa-reddit" aria-hidden="true" title="<?php esc_attr_e('Reddit','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('dribbblelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('dribbblelink') ); ?>" target="_blank" rel="nofollow" class="social-dribbble" aria-label="<?php esc_attr_e('Dribbble Button','cleanwp'); ?>"><i class="fab fa-dribbble" aria-hidden="true" title="<?php esc_attr_e('Dribbble','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('flipboardlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('flipboardlink') ); ?>" target="_blank" rel="nofollow" class="social-flipboard" aria-label="<?php esc_attr_e('Flipboard Button','cleanwp'); ?>"><i class="fab fa-flipboard" aria-hidden="true" title="<?php esc_attr_e('Flipboard','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('bloggerlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('bloggerlink') ); ?>" target="_blank" rel="nofollow" class="social-blogger" aria-label="<?php esc_attr_e('Blogger Button','cleanwp'); ?>"><i class="fab fa-blogger" aria-hidden="true" title="<?php esc_attr_e('Blogger','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('etsylink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('etsylink') ); ?>" target="_blank" rel="nofollow" class="social-etsy" aria-label="<?php esc_attr_e('Etsy Button','cleanwp'); ?>"><i class="fab fa-etsy" aria-hidden="true" title="<?php esc_attr_e('Etsy','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('behancelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('behancelink') ); ?>" target="_blank" rel="nofollow" class="social-behance" aria-label="<?php esc_attr_e('Behance Button','cleanwp'); ?>"><i class="fab fa-behance" aria-hidden="true" title="<?php esc_attr_e('Behance','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('amazonlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('amazonlink') ); ?>" target="_blank" rel="nofollow" class="social-amazon" aria-label="<?php esc_attr_e('Amazon Button','cleanwp'); ?>"><i class="fab fa-amazon" aria-hidden="true" title="<?php esc_attr_e('Amazon','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('meetuplink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('meetuplink') ); ?>" target="_blank" rel="nofollow" class="social-meetup" aria-label="<?php esc_attr_e('Meetup Button','cleanwp'); ?>"><i class="fab fa-meetup" aria-hidden="true" title="<?php esc_attr_e('Meetup','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('mixcloudlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('mixcloudlink') ); ?>" target="_blank" rel="nofollow" class="social-mixcloud" aria-label="<?php esc_attr_e('Mixcloud Button','cleanwp'); ?>"><i class="fab fa-mixcloud" aria-hidden="true" title="<?php esc_attr_e('Mixcloud','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('slacklink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('slacklink') ); ?>" target="_blank" rel="nofollow" class="social-slack" aria-label="<?php esc_attr_e('Slack Button','cleanwp'); ?>"><i class="fab fa-slack" aria-hidden="true" title="<?php esc_attr_e('Slack','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('snapchatlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('snapchatlink') ); ?>" target="_blank" rel="nofollow" class="social-snapchat" aria-label="<?php esc_attr_e('Snapchat Button','cleanwp'); ?>"><i class="fab fa-snapchat" aria-hidden="true" title="<?php esc_attr_e('Snapchat','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('spotifylink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('spotifylink') ); ?>" target="_blank" rel="nofollow" class="social-spotify" aria-label="<?php esc_attr_e('Spotify Button','cleanwp'); ?>"><i class="fab fa-spotify" aria-hidden="true" title="<?php esc_attr_e('Spotify','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('yelplink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('yelplink') ); ?>" target="_blank" rel="nofollow" class="social-yelp" aria-label="<?php esc_attr_e('Yelp Button','cleanwp'); ?>"><i class="fab fa-yelp" aria-hidden="true" title="<?php esc_attr_e('Yelp','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('wordpresslink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('wordpresslink') ); ?>" target="_blank" rel="nofollow" class="social-wordpress" aria-label="<?php esc_attr_e('WordPress Button','cleanwp'); ?>"><i class="fab fa-wordpress" aria-hidden="true" title="<?php esc_attr_e('WordPress','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('twitchlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('twitchlink') ); ?>" target="_blank" rel="nofollow" class="social-twitch" aria-label="<?php esc_attr_e('Twitch Button','cleanwp'); ?>"><i class="fab fa-twitch" aria-hidden="true" title="<?php esc_attr_e('Twitch','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('telegramlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('telegramlink') ); ?>" target="_blank" rel="nofollow" class="social-telegram" aria-label="<?php esc_attr_e('Telegram Button','cleanwp'); ?>"><i class="fab fa-telegram" aria-hidden="true" title="<?php esc_attr_e('Telegram','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('bandcamplink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('bandcamplink') ); ?>" target="_blank" rel="nofollow" class="social-bandcamp" aria-label="<?php esc_attr_e('Bandcamp Button','cleanwp'); ?>"><i class="fab fa-bandcamp" aria-hidden="true" title="<?php esc_attr_e('Bandcamp','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('quoralink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('quoralink') ); ?>" target="_blank" rel="nofollow" class="social-quora" aria-label="<?php esc_attr_e('Quora Button','cleanwp'); ?>"><i class="fab fa-quora" aria-hidden="true" title="<?php esc_attr_e('Quora','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('foursquarelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('foursquarelink') ); ?>" target="_blank" rel="nofollow" class="social-foursquare" aria-label="<?php esc_attr_e('Foursquare Button','cleanwp'); ?>"><i class="fab fa-foursquare" aria-hidden="true" title="<?php esc_attr_e('Foursquare','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('deviantartlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('deviantartlink') ); ?>" target="_blank" rel="nofollow" class="social-deviantart" aria-label="<?php esc_attr_e('DeviantArt Button','cleanwp'); ?>"><i class="fab fa-deviantart" aria-hidden="true" title="<?php esc_attr_e('DeviantArt','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('imdblink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('imdblink') ); ?>" target="_blank" rel="nofollow" class="social-imdb" aria-label="<?php esc_attr_e('IMDB Button','cleanwp'); ?>"><i class="fab fa-imdb" aria-hidden="true" title="<?php esc_attr_e('IMDB','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('vklink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('vklink') ); ?>" target="_blank" rel="nofollow" class="social-vk" aria-label="<?php esc_attr_e('VK Button','cleanwp'); ?>"><i class="fab fa-vk" aria-hidden="true" title="<?php esc_attr_e('VK','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('codepenlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('codepenlink') ); ?>" target="_blank" rel="nofollow" class="social-codepen" aria-label="<?php esc_attr_e('Codepen Button','cleanwp'); ?>"><i class="fab fa-codepen" aria-hidden="true" title="<?php esc_attr_e('Codepen','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('jsfiddlelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('jsfiddlelink') ); ?>" target="_blank" rel="nofollow" class="social-jsfiddle" aria-label="<?php esc_attr_e('JSFiddle Button','cleanwp'); ?>"><i class="fab fa-jsfiddle" aria-hidden="true" title="<?php esc_attr_e('JSFiddle','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('stackoverflowlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('stackoverflowlink') ); ?>" target="_blank" rel="nofollow" class="social-stackoverflow" aria-label="<?php esc_attr_e('Stack Overflow Button','cleanwp'); ?>"><i class="fab fa-stack-overflow" aria-hidden="true" title="<?php esc_attr_e('Stack Overflow','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('stackexchangelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('stackexchangelink') ); ?>" target="_blank" rel="nofollow" class="social-stackexchange" aria-label="<?php esc_attr_e('Stack Exchange Button','cleanwp'); ?>"><i class="fab fa-stack-exchange" aria-hidden="true" title="<?php esc_attr_e('Stack Exchange','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('bsalink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('bsalink') ); ?>" target="_blank" rel="nofollow" class="social-buysellads" aria-label="<?php esc_attr_e('BuySellAds Button','cleanwp'); ?>"><i class="fab fa-buysellads" aria-hidden="true" title="<?php esc_attr_e('BuySellAds','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('web500pxlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('web500pxlink') ); ?>" target="_blank" rel="nofollow" class="social-web500px" aria-label="<?php esc_attr_e('500px Button','cleanwp'); ?>"><i class="fab fa-500px" aria-hidden="true" title="<?php esc_attr_e('500px','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('ellolink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('ellolink') ); ?>" target="_blank" rel="nofollow" class="social-ello" aria-label="<?php esc_attr_e('Ello Button','cleanwp'); ?>"><i class="fab fa-ello" aria-hidden="true" title="<?php esc_attr_e('Ello','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('discordlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('discordlink') ); ?>" target="_blank" rel="nofollow" class="social-discord" aria-label="<?php esc_attr_e('Discord Button','cleanwp'); ?>"><i class="fab fa-discord" aria-hidden="true" title="<?php esc_attr_e('Discord','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('goodreadslink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('goodreadslink') ); ?>" target="_blank" rel="nofollow" class="social-goodreads" aria-label="<?php esc_attr_e('Goodreads Button','cleanwp'); ?>"><i class="fab fa-goodreads" aria-hidden="true" title="<?php esc_attr_e('Goodreads','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('odnoklassnikilink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('odnoklassnikilink') ); ?>" target="_blank" rel="nofollow" class="social-odnoklassniki" aria-label="<?php esc_attr_e('Odnoklassniki Button','cleanwp'); ?>"><i class="fab fa-odnoklassniki" aria-hidden="true" title="<?php esc_attr_e('Odnoklassniki','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('houzzlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('houzzlink') ); ?>" target="_blank" rel="nofollow" class="social-houzz" aria-label="<?php esc_attr_e('Houzz Button','cleanwp'); ?>"><i class="fab fa-houzz" aria-hidden="true" title="<?php esc_attr_e('Houzz','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('pocketlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('pocketlink') ); ?>" target="_blank" rel="nofollow" class="social-pocket" aria-label="<?php esc_attr_e('Pocket Button','cleanwp'); ?>"><i class="fab fa-get-pocket" aria-hidden="true" title="<?php esc_attr_e('Pocket','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('xinglink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('xinglink') ); ?>" target="_blank" rel="nofollow" class="social-xing" aria-label="<?php esc_attr_e('XING Button','cleanwp'); ?>"><i class="fab fa-xing" aria-hidden="true" title="<?php esc_attr_e('XING','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('googleplaylink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('googleplaylink') ); ?>" target="_blank" rel="nofollow" class="social-googleplay" aria-label="<?php esc_attr_e('Google Play Button','cleanwp'); ?>"><i class="fab fa-google-play" aria-hidden="true" title="<?php esc_attr_e('Google Play','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('slidesharelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('slidesharelink') ); ?>" target="_blank" rel="nofollow" class="social-slideshare" aria-label="<?php esc_attr_e('SlideShare Button','cleanwp'); ?>"><i class="fab fa-slideshare" aria-hidden="true" title="<?php esc_attr_e('SlideShare','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('dropboxlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('dropboxlink') ); ?>" target="_blank" rel="nofollow" class="social-dropbox" aria-label="<?php esc_attr_e('Dropbox Button','cleanwp'); ?>"><i class="fab fa-dropbox" aria-hidden="true" title="<?php esc_attr_e('Dropbox','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('paypallink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('paypallink') ); ?>" target="_blank" rel="nofollow" class="social-paypal" aria-label="<?php esc_attr_e('PayPal Button','cleanwp'); ?>"><i class="fab fa-paypal" aria-hidden="true" title="<?php esc_attr_e('PayPal','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('viadeolink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('viadeolink') ); ?>" target="_blank" rel="nofollow" class="social-viadeo" aria-label="<?php esc_attr_e('Viadeo Button','cleanwp'); ?>"><i class="fab fa-viadeo" aria-hidden="true" title="<?php esc_attr_e('Viadeo','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('wikipedialink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('wikipedialink') ); ?>" target="_blank" rel="nofollow" class="social-wikipedia" aria-label="<?php esc_attr_e('Wikipedia Button','cleanwp'); ?>"><i class="fab fa-wikipedia-w" aria-hidden="true" title="<?php esc_attr_e('Wikipedia','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('skypeusername') ) : ?>
            <a href="skype:<?php echo esc_html( cleanwp_get_option('skypeusername') ); ?>?chat" class="social-skype" aria-label="<?php esc_attr_e('Skype Button','cleanwp'); ?>"><i class="fab fa-skype" aria-hidden="true" title="<?php esc_attr_e('Skype','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('emailaddress') ) : ?>
            <a href="mailto:<?php echo esc_html( cleanwp_get_option('emailaddress') ); ?>" class="social-email" aria-label="<?php esc_attr_e('Email Us Button','cleanwp'); ?>"><i class="far fa-envelope" aria-hidden="true" title="<?php esc_attr_e('Email Us','cleanwp'); ?>"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('rsslink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('rsslink') ); ?>" target="_blank" rel="nofollow" class="social-rss" aria-label="<?php esc_attr_e('RSS Button','cleanwp'); ?>"><i class="fas fa-rss" aria-hidden="true" title="<?php esc_attr_e('RSS','cleanwp'); ?>"></i></a><?php endif; ?>
</div>
<?php } ?>
</div>

<?php if ( cleanwp_is_primary_menu_active() ) { ?>
<nav id="site-navigation" class="main-navigation clearfix" itemscope="itemscope" itemtype="http://schema.org/SiteNavigationElement" role="navigation">
    <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php echo esc_html( cleanwp_primary_menu_text() ); ?></button>
    <?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
</nav><!-- #site-navigation -->
<?php } ?>

<?php cleanwp_after_primary_menu(); ?>

</header><!--end masthead-->

<?php cleanwp_after_header(); ?>

<div id="content" class="site-content">